all.Ritss<-function(){
     cat("\n")
     note_for_Ritss_input()
     cat("\n")
     note_for_close_window()
     RitSSpar<-data.frame(parameter=c("LPV","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))
     RitSSpar<-edit(RitSSpar)
##     RitSSpar<-zcheck(RitSSpar)
     cat("\n")
     Rit.ss(RitSSpar[5,2],RitSSpar[4,2],RitSSpar[3,2],RitSSpar[2,2],RitSSpar[1,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     note_for_Ritss_output()
     show(samplesStats("*"))
     cat("\n") 
     C<-Ritcpr(samplesStats("ka"),RitSSpar[2,2],RitSSpar[3,2],RitSSpar[4,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cmss_pr (mg/L)")
     output1<-coutput
     show(coutput)
     C<-Ritcpr(samplesStats("ka"),RitSSpar[2,2],RitSSpar[3,2],RitSSpar[3,2])
     sim<-matrix(C[1 ,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     output2<-coutput
     show(coutput)    
     cat("\n")   
     Rit.more()
}